==> haskell-snap-core-1.0.3.2-34-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-core
version: 1.0.3.2
id: snap-core-1.0.3.2-4w9ejHWGhznHC5M2RFcE5S
key: snap-core-1.0.3.2-4w9ejHWGhznHC5M2RFcE5S
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    This library contains the core definitions and types for the Snap framework,
    including:
    .
    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)
    .
    2. A monad for programming web handlers called \"Snap\", which allows:
    .
    * Stateful access to the HTTP request and response objects
    .
    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together
    .
    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing
    .
    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".
category: Web, Snap, IO-Streams
abi: 8849abf9af952f257d86a20c067102fc
exposed: True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy
hidden-modules: Snap.Internal.Instances Snap.Internal.Routing
                Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
                Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads
import-dirs: /usr/lib/ghc-8.6.1/site-local/snap-core-1.0.3.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/snap-core-1.0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/snap-core-1.0.3.2
hs-libraries: HSsnap-core-1.0.3.2-4w9ejHWGhznHC5M2RFcE5S
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    attoparsec-0.13.2.2-FwHjzt71DhSHhjVAq259Rs base-4.12.0.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    io-streams-1.5.0.1-GecMReDhwXu2KpH81Ly9XL
    lifted-base-0.2.3.12-KjF0X1vOMmEKx0umQAcDw
    monad-control-1.0.2.3-GTHTd3ANl4bLcDnP0abGmh mtl-2.2.2
    network-2.7.0.2-AhHTxdUIBGH70CptKdvDEL
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    readable-0.3.1-7I5EIROpRuwBi3cHo2WBVY
    regex-posix-0.95.2-BB6ZndJQrzY62dvJ2oZ3za text-1.2.3.1 time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-IJREwika6Q09fUjnypf1lr
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unordered-containers-0.2.9.0-8YwmaeVELNEGd3AzVghTJw
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html: /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-core-1.0.3.2-35-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-core
version: 1.0.3.2
id: snap-core-1.0.3.2-1pW7A9lYD71lw8g66QDA8
key: snap-core-1.0.3.2-1pW7A9lYD71lw8g66QDA8
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    This library contains the core definitions and types for the Snap framework,
    including:
    .
    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)
    .
    2. A monad for programming web handlers called \"Snap\", which allows:
    .
    * Stateful access to the HTTP request and response objects
    .
    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together
    .
    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing
    .
    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".
category: Web, Snap, IO-Streams
abi: 4aa89efd6295621c87c00d59727eae50
exposed: True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy
hidden-modules: Snap.Internal.Instances Snap.Internal.Routing
                Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
                Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads
import-dirs: /usr/lib/ghc-8.6.1/site-local/snap-core-1.0.3.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/snap-core-1.0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/snap-core-1.0.3.2
hs-libraries: HSsnap-core-1.0.3.2-1pW7A9lYD71lw8g66QDA8
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    attoparsec-0.13.2.2-HPD0YgNwhBr5J2x8QxeYlI base-4.12.0.0
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    directory-1.3.3.0 filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    io-streams-1.5.0.1-AAVyz4a7cll6ixTwZkniW9
    lifted-base-0.2.3.12-1BBmya7PRMr9cWJ3KIOV9b
    monad-control-1.0.2.3-EVTsaRMDq1PEP58gODzmjM mtl-2.2.2
    network-2.7.0.2-2yr2pvLPehY6oGeYQ5TSho
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    readable-0.3.1-7I5EIROpRuwBi3cHo2WBVY
    regex-posix-0.95.2-BB6ZndJQrzY62dvJ2oZ3za text-1.2.3.1 time-1.8.0.2
    transformers-0.5.5.0
    transformers-base-0.4.5.2-IrU9RLUyNmJ8YkbNrC8RMj
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unordered-containers-0.2.9.0-LB7iMl6A8usDj0EAzhnafU
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html: /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
